[![Python package](https://github.com/AusClimateService/axiom/actions/workflows/ci.yml/badge.svg)](https://github.com/AusClimateService/axiom/actions/workflows/ci.yml) [![Build and upload to PyPI](https://github.com/AusClimateService/axiom/actions/workflows/pypi-release.yml/badge.svg)](https://github.com/AusClimateService/axiom/actions/workflows/pypi-release.yml)

# Axiom

*An established rule or principle, a self-evident truth*

Axiom is a prototype utility for validating/applying metadata templates for scientific data files.

Documentation can be found in the docs directory of this repository.
